#!/bin/bash

ORIGD=$PWD
ARCHIVE_DIR=$(dirname $0)

for i in $(seq 1 $#); do
	case "$1" in
		"-h"|"--help") \
			HELP=yes && shift ;;
		"-v"|"--verbose") \
			VERBOSE=yes && shift ;;
		"--destdir="*) \
			DESTDIR=$(echo $1 | sed 's%--destdir=%%g') && shift ;;
		esac
done

if [[ "$HELP" = "yes" ]]; then
	echo
	echo "This script is a trivial installer for the Ghost Kernel"
	echo "it is a part of ghost-tools." && echo
	echo "usage : ./install.sh to install this TARGET kernel binary"
	echo "        archive or use ./uninstall.sh to remove it." && echo
	echo "There is just three options to install:"
	echo "      -v|--verbose     -- to see files which are installed,"
	echo "      -h|--help        -- this help,"
	echo "      --destdir=PATH   -- to specify another root directory (default \"/\")."
	echo 
	exit 0
fi

cd $ARCHIVE_DIR

if [[ -n $DESTDIR ]]; then
	mkdir -p $DESTDIR
fi

if [[ -d files ]]; then
	if [[ "$VERBOSE" = "yes" ]]; then \
		echo "Install files ..." && echo && \
		cp -va ./files/* $DESTDIR/ 2>/dev/null ; \
	else \
		cp -a ./files/* $DESTDIR/ 2>/dev/null ; \
	fi && \
	pushd files 1>/dev/null && \
	find ./ | grep -v '^./$' | grep -v .path | sed s%^./%$DESTDIR/%g > ../INSTALLED_FILES.log && \
	find ./ | grep -v '^./$' | grep -v .path | sed s%^./%$DESTDIR/%g > ../.INSTALLED_FILES.bak && \
	if [[ -n $DESTDIR ]]; then \
		echo "DESTDIR=$DESTDIR" >> ../INSTALLED_FILES.log && \
		echo "DESTDIR=$DESTDIR" >> ../.INSTALLED_FILES.bak ;
	fi && \
	popd 1>/dev/null && \
	{ echo && echo "Installation finished : SUCCESS" && echo ;} || \
		{ echo && echo "ERROR : Installation not finished : ECHEC" && \
			echo "ERROR : Make sure you have the appropriate privileges to install kernel" && echo ;} ; \
else
	echo 
	echo "ERROR: You must run this script in the archives generated by ghost-tools !!"
	echo
fi

cd $ORIGD 

